#!/usr/bin/perl
use lib '/home/martin/ethereal/mgmt';

#################################################################################
# Created       : Martin Foster
# Modified      : 04-Nov-2004
#################################################################################
#
# Emailer - Simpler Emailer part of Ethereal Realms allowing one to create
#           contact forms as necessary.
# Copyright (C) 2000-2006  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 29-26503 TWP RD 511
#                 Spruce Grove, Alberta
#                 T7Y 1G4
#
#################################################################################

use CGI;							# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
use Text::Wrap;							# Text wrapping functionality
use strict;							# Strict variable enforcement

use Ethereal::Database;						# Database handler
use Ethereal::Mail;						# Mail handler
use Ethereal::Param;						# Parameter control

#################################################################################
# Gobal override
#################################################################################
$CGI::POST_MAX=1024 * 50;					# Maximum posts
$CGI::DISABLE_UPLOADS = 1;					# Disable uploads

#################################################################################
# Data Members
#################################################################################
my $cgi;							# Common gateway interface handle
my $database;							# Database handle
my $param;							# Parameter handle
my $send;							# Mail handler

my $notice;							# Notice informing of generation
my $redirect;							# Redirection to a page
my $valid;							# Validating information

my @validate = qw(RCPT FROM NAME SUBJECT MESSAGE REDIRECT);	# Components to validate

my %system;							# System hash


#################################################################################
# Program Area
#################################################################################

	# Initial handles
	$cgi      = new CGI;	
	$database = new Ethereal::Database();

	# Connect and fetch
	$database->Connect($cgi);	

	# Parameter handling
	$param = new Ethereal::Param($database, $cgi);
	$param->GetParam();
	
	# Link with hash
	$database->GetHashSystem(\%system);


	# Validate information
	foreach $valid (@validate)
	{
		# Terminate if things are not valid
		die("Invalid parameter: EMAIL_$valid") unless (defined($param->{"EMAIL_$valid"})); 
	}


	# Fetch notice
	($notice) = $database->DocumentGetEmailer();

	# Redirection
	$redirect = (length($param->{'EMAIL_REDIRECT'}) > 10) ? $param->{'EMAIL_REDIRECT'} : $cgi->url(-base=>1);


	# Send mail
	# Initiate instance
	$send = tie(*MAIL, 'Ethereal::Mail', $database);

	# Initial setup
	$send->SetSubject($param->{'EMAIL_SUBJECT'});

	# Recipients
	$send->AddFrom("$param->{EMAIL_NAME} <$param->{EMAIL_FROM}>");
	$send->AddTo($param->{'EMAIL_RCPT'});

	# Message
	print MAIL $param->{'EMAIL_MESSAGE'} . $notice;

	# Close and Send
	close(MAIL);


	# Redirect user
	print $cgi->redirect($redirect);
