#!/usr/bin/perl
use lib '/home/martin/ethereal/mgmt';

#################################################################################
# Created       : Martin Foster
# Modified      : 01-Sep-2005
#################################################################################
#
# Thumbnail - Script used to re-generate all thumbnails on a gallery site.
# Copyright (C) 2000-2004  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 29-26503 TWP RD 511
#                 Spruce Grove, Alberta
#                 T7Y 1G4
#
#################################################################################

use strict;							# Strict variable enforcement

use Ethereal::Database;						# Database handler
use Ethereal::Image;						# Image manipulation handler
use Ethereal::Home;						# Homepage and directory handler


#################################################################################
# Data Members
#################################################################################
my $database;							# Database handle
my $image;							# Image handle
my $page;							# Homepage handle

my $res;							# Result handle
my $statement;							# Query
my $template;							# Template to use

my $site;							# Site schema
my $file;							# Filename
my $dir;							# Directory
my $ext;							# Extension
my $exif;							# Exif tag management

my $vheight;							# Viewing demensions
my $vwidth;
my $fheight;							# Full view demensions
my $fwidth;
my $size;							# Full image size

my %gal;							# Gallery hash

#################################################################################
# Program Area
#################################################################################

	# Make sure schema is specified
	if ($site = shift(@ARGV))
	{
		# Initial handles
		$database = new Ethereal::Database();

		# Connect and Fetch
		$database->Connect();
	
		# Set search paths
		$database->Write("SET SEARCH_PATH TO $site,public");
	
		# Link with hash
		$database->GetHashGallery(\%gal);


		# Setup with base directory
		$image = new Ethereal::Image($database, '/tmp');
		$page  = new Ethereal::Home($database, '/tmp');

		# Deterine extension
		$ext = $image->{'FORMAT'};


		# Display
		print "Starting process for $site!\n\n";


		# Contacts
		$database->Pull(\$statement, "SELECT 
			  GalleryID      AS \"GalleryID\",
			  WorkID         AS \"WorkID\",
			  WorkImage      AS \"WorkImage\"
			FROM Work w
			WHERE WorkImage IS NOT NULL
			ORDER BY GalleryID, WorkID");

		# Loop and publish
		# Continue as long as there are works
		while ($res = $statement->fetchrow_hashref())
		{
			# Display
			print ' /' . $res->{'GalleryID'} . '/' . $res->{'WorkID'} . "\t ";


			# Verify validity
			$res->{'WorkImage'} =~ /^.*\.(\w+)$/;

			# Capture files
			$file = $1;

			# Update
			print uc($file);

			# Set base directory
			$image->{'BASEDIR'} = $gal{'SetRoot'} . '/' 
				. $res->{'GalleryID'} . '/'
				. $res->{'WorkID'};

			# Check if file exists
			if (-f $image->{'BASEDIR'} . '/work.' . $file)
			{
				# Update
				print " .";

				# Check for exif information
				$exif = $image->ExifFormat('work.' . $file);
				
				# Update
				print ".";

				# Generate thumbnail
				$image->Thumbnail('work.' . $file);

				($vwidth, $vheight, $size) = $image->Size("view-work.$file");
				($fwidth, $fheight) = $image->Size("work.$file");

				# Update
				print ".";

				# Determine directory
				$dir = $gal{'SetUrl'} . '/' 
					. $res->{'GalleryID'} . '/'
					. $res->{'WorkID'};
			

				# Reset thumbail preferences
				$database->Quick("UPDATE Work
					SET WorkImageThumbnail=?,
					    WorkImage=?,
					    WorkImageSize=?,
					    WorkImageWidth=?,
					    WorkImageHeight=?,
					    WorkImageExif=?,
					    WorkImageView=?,
					    WorkImageFull=?
					WHERE GalleryID=?
					  AND WorkID=?",

				 "$dir/thumb-work-ful.$ext",
				 "$dir/view-work.$file",
				 $size,
				 $fwidth,
				 $fheight,
				 $exif,
				 "width='$vwidth' height='$vheight'",
				 "width='$fwidth' height='$fheight'",
				 $res->{'GalleryID'},
				 $res->{'WorkID'}
				);

				# Update
				print ". Done!\n";
			}

			# Does not exist
			else
			{
				# Remove directory
				$page->DirClear($image->{'BASEDIR'}) if (-d $image->{'BASEDIR'});
				
				# Remove entry
				$database->Quick("DELETE FROM Work
				WHERE GalleryID=?
				  AND WorkID=?",

				$res->{'GalleryID'},
				$res->{'WorkID'}
				);

				# Update
				print ". Skipped!\n";
			}
		}
	
		# End
		$statement->finish();


		# Final notice
		print "The update is complete! If the file format has changed, you may"
		    . "have old entries lingering on your system.   In order to"
		    . "correct these, simply run the command below:\n"
                    . "find " . $gal{'SetRoot'} . "/ -type f -name *.jpg -exec rm -f {}\;\n\n"
                    . "NOTE: Change the extension to match the ones on the stale files.\n\n";
	}

	# Otherwise warn
	else
	{
		# Simple useage instead of error
		print "Ethereal Realms thumbnail generator command-line interface:\n";
		print "Usage: ./thumb.pl {schema}\n\n";
	}


#################################################################################
# Sub-Routines
#################################################################################
